EmptyDartBoardFeature class

An empty feature to use as a default if an feature can't be found

Inheritance

Constructors

EmptyDartBoardFeature()

Properties

appDecorations → List<DartBoardDecoration>
The app decorations (global)
no setterinherited
dependencies → List<DartBoardFeature>
no setterinherited
enabled → bool
This can be used to allow an extension to exclude itself. E.g. Based on platform
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
implementationName → String
no setterinherited
isIntegrationFeature → bool
This is a hint if a feature is "Integration" or not. The only difference here is that "Integration" features are not displayed in the dependency graph (to many edges, looks ugly)
no setterinherited
methodHandlers → Map<String, MethodCallHandler>
This map of method handlers can be used to define callbacks
no setterinherited
namespace → String
A namespace to prefix to reference this feature by Please make it unique
no setteroverride
pageDecorationAllowList → List<String>
Allow list for page decorations in the format "/route:page_decoration_name"
no setterinherited
pageDecorationDenyList → List<String>
Deny list for page decorations in the format "/route:page_decoration_name"
no setterinherited
pageDecorations → List<DartBoardDecoration>
The page decorations (page level)
no setterinherited
routes → List<RouteDefinition>
The route definitions
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited